export = loginSocialUser;
/**
 * Function to login social user
 * ==============================================================================
 * @description This function logs in the user after 'handleSocialDb' function finishes
 * the user creation or confirmation process
 *
 * @async
 *
 * @param {object} params - function parameters inside an object
 * @param {{
 *  first_name: string,
 *  last_name: string,
 *  email: string,
 *  social_id: string|number,
 * }} params.user - user object
 * @param {string} params.social_platform - Whether its "google" or "facebook" or "github"
 * @param {any} [params.invitation] - A query object if user was invited
 * @param {string} [params.database] - Target Database
 * @param {string[]} [params.additionalFields] - Additional fields to be added to the user payload
 * @param {boolean} [params.useLocal]
 *
 * @returns {Promise<import("../../../types").APILoginFunctionReturn>}
 */
declare function loginSocialUser({ user, social_platform, invitation, database, additionalFields, useLocal, }: {
    user: {
        first_name: string;
        last_name: string;
        email: string;
        social_id: string | number;
    };
    social_platform: string;
    invitation?: any;
    database?: string;
    additionalFields?: string[];
    useLocal?: boolean;
}): Promise<import("../../../types").APILoginFunctionReturn>;
